@@ -42,10 +42,23 @@ mockPhenotypeR <- function(nPerson = 100,
     omock::mockDeath(seed = seed) |>
     omock::mockCohort(name = "my_cohort", numberCohorts = 2, seed = seed)
 
+  cdm_local$device_exposure <- dplyr::tibble(
+    "device_exposure_id" = NA_integer_,
+    "person_id" = NA_integer_,
+    "device_concept_id" = NA_integer_,
+    "device_exposure_start_date" = as.Date(NA),
+    "device_type_concept_id" = NA_integer_,
+    "device_source_concept_id"	= NA_integer_
+  )
+
   cdm <- CDMConnector::copyCdmTo(con = con,
                                    cdm = cdm_local,
                                    schema = writeSchema,
                                    overwrite = TRUE)
+
+  cdm <- CodelistGenerator::buildAchillesTables(cdm) |>
+    suppressMessages()
+
   attr(cdm, "write_schema") <- writeSchema
 
   return(cdm)
